@@ -28,17 +28,16 @@
 #include <string.h>
 #include <errno.h>
 
-#include <error.h>
-
-#ifdef LOCALE_WORKS
+#if HAVE_LOCALE_H
 # include <locale.h>
-#else
-# define setlocale(Category, Locale)	/* empty */
 #endif
 
+/* Gnulib headers. */
+#include "error.h"
 #include "gettext.h"
 #define _(String) dgettext (PACKAGE, String)
 
+/* Libidn headers. */
 #include <stringprep.h>
 #include <punycode.h>
 #include <idna.h>
@@ -67,7 +66,9 @@ main (int argc, char *argv[])
   unsigned cmdn = 0;
   int rc;
 
+#ifdef HAVE_SETLOCALE
   setlocale (LC_ALL, "");
+#endif
   program_name = argv[0];
   bindtextdomain (PACKAGE, LOCALEDIR);
   textdomain (PACKAGE);
